//Copyright (C) 2015  Michael Rackl
//
//This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License along with this program; if not, see <http://www.gnu.org/licenses/>. 

// Author: Michael Rackl (rackl@ibracon.de)
// Date of creation: Apr 9, 2013
// includes functions for regression analysis
// ***********************************************************************
// quality function
function f = quality(C)
    global mStrain mStress mShearStr flag
    // initialise quality functions
       // absolute error
            f = 0;
            ftc = 0;
            fs = 0;
            // compute new value for f, which has to be minimised (Tension/Compression)
            for i = 1:size(mStrain,'r')
                qf(i) = (mStress(i) - OgdenTensCompLaw(C,mStrain(i)))^2;
                ftc  = ftc + qf(i);
            end
            // compute new value for f, which has to be minimised (Simple shear)
            for i = 1:size(mShearStr,'r')
                sqf(i) = (mShearTau(i) - OgdenSimpleShearLaw(C,mShearStr(i)))^2;
                fs  = fs + sqf(i);
            end
            // add results of quality functions
            f = ftc+fs;
endfunction

// ************************************************************************
// ***********************************************************************
// quality function
function f = qualityNorm(C)
    global mStrain mStress mShearStr
    // initialise quality functions
       // normalised error
            f = 0;
            ftc = 0;
            fs = 0;
            // compute new value for f, which has to be minimised (Tension/Compression)
            for i = 1:size(mStrain,'r')
                if mStress(i) ~= 0 then
                    qf(i) = (1 - ((OgdenTensCompLaw(C,mStrain(i)))/(mStress(i))))^2;
                    ftc = ftc + qf(i);
                else
                    qf(i) = ((mStress(i) - OgdenTensCompLaw(C,mStrain(i))))^2;
                    ftc = ftc + qf(i);
                end
            end
            // compute new value for f, which has to be minimised (Simple shear)
            for i = 1:size(mShearStr,'r')
                if mShearTau(i) ~= 0 then
                    sqf(i) = (1 - ((OgdenSimpleShearLaw(C,mShearStr(i)))/(mShearTau(i))))^2;
                    fs = fs + sqf(i);
                else
                    sqf(i) = (mShearTau(i) - OgdenSimpleShearLaw(C,mShearStr(i)))
                    fs = fs + sqf(i);
                end

            end
            // add results of quality functions
            f = ftc+fs;
endfunction
// ************************************************************************
// ************************************************************************
// ************************************************************************
// ************************************************************************
// Compute determinant of regression
// meData: measured data
// coData: predicted data from regression model
// p:    number of independent coefficients used in regression model
function CoR = CoD(meData, coData, p)
    n = size(meData,'r');
    mid = mean(meData);         // mean of measurement data
    N=0;                        // initialise nominator and denominator sums
    D=0;
    for i = i:n  // compute nominator and denominator sums
        N = N + (meData(i) - coData(i))^2;
        D = D + (meData(i) - mid)^2;
    end
    R = 1 - (N/D);
    // compute corrected coefficient of determination to account for multiple
    // regression coefficients
    CoR = 1 - (1-R) * ( (n-1)/(n-p-1) );
endfunction
// ************************************************************************
// ************************************************************************
// ************************************************************************
// plot results to console
// C: material constants vector (column vector)
function ShowResults(C)
k=1;
for i = 1:2:size(C,'r')
    disp([ "alpha_" + string(k) + "=" string(C(i)) ])
    disp([ "mu_"  + string(k) + "=" string(C(i+1)) ])
    k=k+1;
end
endfunction
