//Copyright (C) 2015  Michael Rackl
//
//This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License along with this program; if not, see <http://www.gnu.org/licenses/>. 

// Author: Michael Rackl (rackl@ibracon.de)
// Date of creation: Apr 9, 2013
//
// Main routing for Ogden model curve fitting
clc
clear
global mStrain mStress mShearStr
exec "AuxFunctions.sci";
exec "OgdenModels.sci";
// ****************************************************************************
// import measurement data from csv-file
// stress in [N/mm^2] = [MPa]
    // read compression/tension data
Raw = csvRead('limbiauniaxial.csv');
    // read simple shear data
SRaw = csvRead("limbiashear.csv");
// save to variables
mStrain =  Raw(:,1);
mStress = Raw(:,2);
mShearStr = SRaw(:,1);
mShearTau = SRaw(:,2);
// ****************************************************************************
// ****************************************************************************
// set starting values for the material constants
//      alpha_1; mu_1; alpha_2; mu_2  ... alpha_n; mu_n
    C0 = [1;1; 1;1; 1;1];
    flag = 0;       // flag=1 use normalized error
                    // flag=0 uses absolute least square root error sum
// ****************************************************************************
// ****************************************************************************
// minimise quality function using Nelder-Mead algorithm
opts = optimset('TolFun',1e-8, 'TolX',1e-9, 'MaxFunEvals',3000, 'Display','final', 'MaxIter', 1000);
disp('Results for Ogden model; order ' +  string(size(C0,"r")/2))
// minimise
if flag==0 then
    // absolute error
    [C, fval, exitflag] = fminsearch(quality, C0, opts)
elseif flag==1 then
    // normalised error
    [C, fval, exitflag] = fminsearch(qualityNorm, C0, opts)
end
C = C';
// write results to console
ShowResults(C)
// generate stress-strain curve with optimised parameter set
for i = 1:size(mStrain, 'r')
    moStress(i) = OgdenTensCompLaw(C, mStrain(i));
end
for i = 1:size(mShearStr, "r")
    moShearStress(i) = OgdenSimpleShearLaw(C,mShearStr(i));
end
// ****************************************************************************
// ****************************************************************************
// compute coefficient of determination
    // Tension/Compression
corMR = CoD(mStress, moStress, size(C,"r"));
    // simple shear
corMRshear = CoD(mShearTau, moShearStress, size(C,"r"));
// ****************************************************************************
// ****************************************************************************
// plot results
    titlefont = 3;
    axesfont = 2;
    labelfont = 2;
    legendfont = 3;
    // plot compression/tension results
title("Curve Fitting")
subplot(1,2,1)
plot(mStrain,mStress, mStrain,moStress)
title('Comp./Tens. results f. Ogden (' + string(size(C,"r")) + ' param.)', "fontsize",titlefont)
xlabel('tensile/compressive strain [-]',"fontsize",labelfont)
ylabel('stress [N/mm^2]',"fontsize",labelfont)
set(gca(),"grid",[1 1])
le = legend('Measurement', ['CoD='+string(corMR)] ,2)
le.font_size = legendfont;
le.clip_state = "on"
le.clip_box = [0,0,20,10]
// ****************************************************************************
    // plot simple shear results
subplot(1,2,2)
plot(mShearStr,mShearTau, mShearStr,moShearStress)
title('Simple Shear results f. Ogden (' + string(size(C,"r")) + ' param.)', "fontsize",titlefont)
xlabel('Simple shear strain [-]',"fontsize",labelfont)
ylabel('Shear stress [N/mm^2]',"fontsize",labelfont)
set(gca(),"grid",[1 1])
le = legend('Measurement', ['CoD='+string(corMRshear)],2)
le.font_size = legendfont;
f.figure_size = [661, 397];
f.background = color(255,255,255);
b = gcf()
b.children.font_size = axesfont;
