//Copyright (C) 2015  Michael Rackl
//
//This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License along with this program; if not, see <http://www.gnu.org/licenses/>. 

// Ogden material model equations
// Author: Michael Rackl (rackl@ibracon.de)
// 25.05.2015
// ************************************************************************
// ************************************************************************
// ************************************************************************
// Material model: Ogden (N-th order), uniaxial Tension/Compression
function g = OgdenTensCompLaw(params, stretch)
    // computes stress from material model according to measured stretch data
    g=0;
    for i = 2:2:size(params,"r")
        re = stretch^(params(i-1)-1);
        lo = stretch^(-(0.5*params(i-1)+1));
        s = params(i) * (re - lo);
        g = g + s;
    end
endfunction
// ************************************************************************
// ************************************************************************
// ************************************************************************
// Material model: Ogden (N-th order), Simple shear
function g = OgdenSimpleShearLaw(params, stretch)
    // computes stress from material model according to measured strain data
    g = 0;
    //// iterate stretch value
    stretch = in(stretch);
    for i = 2:2:size(params,"r")
        re = stretch^(params(i-1));
        lo = stretch^(-(params(i-1)));
        s = params(i) * (re - lo)/(stretch+stretch^(-1));
        g = g + s;
    end
endfunction
// ************************************************************************
// ************************************************************************
// ************************************************************************
function aus = in(arg)
    lambda = 1;
    while abs((arg+lambda^(-1)-lambda)) > 1e-6
        lambda = arg + lambda^(-1);
    end
    aus = lambda;
endfunction
