//Copyright (C) 2015  Michael Rackl
//
//This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License along with this program; if not, see <http://www.gnu.org/licenses/>. 

// Yeoh material model equations
// Author: Michael Rackl (rackl@ibracon.de)
// 25.05.2015
// ************************************************************************
// ************************************************************************
// ************************************************************************
// Material model: Yeoh (N-th order), uniaxial Tension/Compression
// paramams: material constants vector
// stretch: stretch from uniaxial tension/compression
function g = YeohTensCompLaw(params, stretch)
    // computes stress from material model according to measured strain data
    g=0;
    for i = 1:size(params,"r")
        re = (stretch^2 + 2*stretch^(-1) - 3)^(i-1);
        lo = (stretch - stretch^(-2));
        s = 2 * i * params(i) * lo * re;
        g = g + s;
    end
endfunction
// ************************************************************************
// ************************************************************************
// ************************************************************************
// Material model: Yeoh (N-th order), Simple shear
// paramams: material constants vector
// stretch: simple shear strain
function g = YeohShearLaw(params, stretch)
    // computes stress from material model according to measured strain data
    g = 0;
    for i = 1:size(params,"r")
        re = (stretch^2)^(i-1);
        lo = 2* i * params(i) * stretch;
        s = lo * re;
        g = g + s;
    end
endfunction
