//Copyright (C) 2015  Michael Rackl
//
//This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License along with this program; if not, see <http://www.gnu.org/licenses/>. 

// Author: Michael Rackl (rackl@ibracon.de)
// Date of creation: Apr 9, 2013
//
// Main routing for Polynomial model curve fitting
clc
clear
global mStrain mStress mShearStr
exec "AuxFunctions.sci";
exec "PolyModels.sci";
// ****************************************************************************
// import measurement data from csv-file
// stress in [N/mm^2] = [MPa]
    // read compression/tension data
Raw = csvRead('limbiauniaxial.csv');
    // read simple shear data
SRaw = csvRead("limbiashear.csv");
// save to variables
mStrain =  Raw(:,1);
mStress = Raw(:,2);
mShearStr = SRaw(:,1);
mShearTau = SRaw(:,2);
// ****************************************************************************
// ****************************************************************************
// set starting values for the material constants
// values correspond with the output; e.g. first output constant goes with the
// first value in the starting vector
    C0 = [1; 1];
    flag = 1;       // flag=1 use normalized error
                    // flag=0 use absolute error
// ****************************************************************************
// ****************************************************************************
if size(C0,"r")==3 then
    disp("NOTICE: Using 3 parameter Mooney-Rivlin model")
    disp("WARNING: Output variable c20 equals c11!")
end
// ****************************************************************************
// ****************************************************************************
// minimise qualtiy function using Nelder-Mead algorithm
opts = optimset('TolFun',1e-10, 'TolX',1e-11, 'MaxFunEvals',3000, 'Display','final', 'MaxIter', 5000);
disp('Results for ' + string(size(C0,"r"))+ ' parameter order Polynominal material')
// minimise
if flag==0 then
    // absolute error
    [C, fval, exitflag] = fminsearch(quality, C0, opts)
elseif flag==1 then
    // normalized error
    [C, fval, exitflag] = fminsearch(qualityNorm, C0, opts)
end
C = C';
// plot results to console
disp([ 'c10 =' string(C(1)) ])
disp([ 'c01 =' string(C(2)) ])
if size(C0,"r")>2 then
    disp([ 'c20 =' string(C(3)) ])
end
if size(C0,"r")>3 then
    disp([ 'c11 =' string(C(4)) ])
end
if size(C0,"r")>4 then
    disp([ 'c02 =' string(C(5)) ])
end
disp(['Polynominal fval =' string(fval)])
disp(['Polynominal exitflag =' string(exitflag)])
// generate stress-strain curve with optimized parameter set
for i = 1:size(mStrain, 'r')
    moStress(i) = PolyTensCompLaw(C, mStrain(i));
end
for i = 1:size(mShearStr, "r")
    moShearStress(i) = PolySimpleShearLaw(C,mShearStr(i));
end
// ****************************************************************************
// ****************************************************************************
// compute coefficient of determination
    // Tension/Compression
corMR = CoD(mStress, moStress, size(C,"r"));
    // simple shear
corMRshear = CoD(mShearTau, moShearStress, size(C,"r"));
// ****************************************************************************
// ****************************************************************************
// plot results
    titlefont = 3;
    axesfont = 2;
    labelfont = 2;
    legendfont = 3;
    // plot compression/tension results
title("Regression Analysis")
subplot(1,2,1)
plot(mStrain,mStress, mStrain,moStress)
title('Comp./Tens. results f. Polynom. (' + string(size(C,"r")) + ' param.)', "fontsize",titlefont)
xlabel('tensile/compressive stretch [-]',"fontsize",labelfont)
ylabel('stress [N/mm^2]',"fontsize",labelfont)
set(gca(),"grid",[1 1])
le = legend('Measurement', ['CoD='+string(corMR)],2)
le.font_size = legendfont;
le.clip_state = "on"
le.clip_box = [0,0,20,10]
// ****************************************************************************
    // plot simple shear results
subplot(1,2,2)
plot(mShearStr,mShearTau, mShearStr,moShearStress)
title('Simple Shear results f. Polynom (' + string(size(C,"r")) + ' param.)', "fontsize",titlefont)
xlabel('Simple shear strain [-]',"fontsize",labelfont)
ylabel('Shear stress [N/mm^2]',"fontsize",labelfont)
set(gca(),"grid",[1 1])
le = legend('Measurement', ['CoD='+string(corMRshear)],2)
le.font_size = legendfont;
f.figure_size = [661, 397];
f.backgroud = color(255,255,255);
b = gcf()
b.children.font_size = axesfont;
