//Copyright (C) 2015  Michael Rackl
//
//This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License along with this program; if not, see <http://www.gnu.org/licenses/>. 

// Polynomial material model equations
// Author: Michael Rackl (rackl@ibracon.de)
// 25.05.2015
// ************************************************************************
// ************************************************************************
// ************************************************************************
// Material model: Polynomial (first and second order + Mooney-Rivlin), uniaxial Tension/Compression
function g = PolyTensCompLaw(params, stretch)
    // computes stress from material model according to measured stretch data
    // support for 1st and 2nd order polynominal model
    //
    // adapts to different orders by reading the no. of parameters handed to
    // the function
    if size(params,"r")==2 then
        params(3) = 0;
        params(4) = 0;
        params(5) = 0;
    elseif size(params,"r")==3 then
        // equals 3 parameter Mooney-Rivlin-Model
        params(5) = 0;
        params(4) = 0;
        g=0;
        lo = 2*params(4)*(stretch^2 + 2*stretch^(-1) - 3);
        re = params(2) * stretch^(-1);
        ka = 2 * params(5) * stretch^(-1) * (stretch^(-2) + 2*stretch - 3);
        ma = 3 * params(3) * (stretch - 1 - stretch^(-1) + stretch^(-2));
        g = 2 * (stretch-(stretch^(-2))) * (params(1) + lo + re + ka + ma);
        return
    elseif size(params,"r") ==5 then
        // no feedback
    else
        disp("Warning: Wrong number of of parameters!")
    end
    g=0;
    lo = 2*params(3)*(stretch^2 + 2*stretch^(-1) - 3);
    re = params(2) * stretch^(-1);
    ka = 2 * params(5) * stretch^(-1) * (stretch^(-2) + 2*stretch - 3);
    ma = 3 * params(4) * (stretch - 1 - stretch^(-1) + stretch^(-2));
    g = 2 * (stretch-(stretch^(-2))) * (params(1) + lo + re + ka + ma);
endfunction
// ************************************************************************
// ************************************************************************
// ************************************************************************
// Material model: Polynomial (first and second order + Mooney-Rivlin), Simple shear
function g = PolySimpleShearLaw(params, stretch)
    // computes stress from material model according to measured strain data
    if size(params,"r")==2 then
        params(3) = 0;
        params(4) = 0;
        params(5) = 0;
    elseif size(params,"r")==3 then
        params(4) = 0;
        params(5) = 0;
    elseif size(params,"r") ==5 then
        // no feedback
    else
        disp("Warning: Wrong number of of parameters!")
    end
    g = 0;
    lo = 4* (params(3) + params(4) + params(5)) * stretch^3;
    g = 2 * (params(1)+params(2)) *stretch + lo;
endfunction
